import sendgrid
from sendgrid.helpers.mail import Mail, Content

def send_email(sendgrid_api_key: str, subject: str, body: str, from_email: str, recipients: list):
    """
    A function to send emails using the sendgrid service.
    A valid sendgrid API keey needs to be passed for the function to work.
    
    Parameters
    ----------
    subject: The subject of the email.
        
    body: The body of text for the email.

    from_email: The email to be used to send the email 
                (this should be set up on the sendgrid website when setting up the sendgrid api key).

    recipients: A list of email addresses to send the email to.
                Or just a string for a single recipient.
        
    sendgrid_api_key: The verified sendgrid api key associated with the sender email.
    
    Returns
    -------
    None
    """
    
    # Create the content to be sent in the email
    content = Content("text/plain", str(body))
    
    # Compile the email info as a Mail object
    mail = Mail(from_email, recipients, str(subject), content)
    
    # Try to send the email
    try:
        sg = sendgrid.SendGridAPIClient(sendgrid_api_key)
        response = sg.client.mail.send.post(request_body=mail.get())

    except Exception as e:
        print("ERROR")
        print(e.message)


from setuptools import setup, find_packages
from pathlib import Path

# Get the current directory of the setup.py file (as this is where the README.md will be too)
current_dir = Path(__file__).parent
long_description = (current_dir / "README.md").read_text()

# Set up the package metadata
setup(
    name="psusannx_email",
    author="Jamie O'Brien",
    description="A package with a function for sending emails easily using sendgrid.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    version="0.1.2",
    packages=find_packages(include=["psusannx_email", "psusannx_email.*"]),
    install_requires=["sendgrid>=6.9.7"]
)